part of firebase_model_notifier.storage.web;

/// Class for handling Firebase storage.
///
/// Basically, you specify the [path] of the local file in [upload] and
/// receive the URL after the upload.
///
/// You can then use [Image.network] or similar to display that URL.
class FirebaseStorageCore {
  FirebaseStorageCore._();

  /// Class for handling Firebase storage.
  ///
  /// Basically, you specify the [path] of the local file in [upload] and
  /// receive the URL after the upload.
  ///
  /// You can then use [Image.network] or similar to display that URL.
  ///
  /// ```
  /// final media = await FirebaseStorageCore.upload("local path");
  /// if(media == null) return;
  /// Image.network(media.url);
  /// ```
  static Future<String> upload(String path) async {
    assert(path.isNotEmpty, "Path is empty.");
    if (path.startsWith("http")) {
      return path;
    }
    final storage =
        readProvider(firebaseStorageProvider("$uuid.${path.split(".").last}"));
    await storage.upload(path);
    return storage.url;
  }

  /// Class for handling Firebase storage.
  ///
  /// Basically, you specify the [bytes] of the local file in [upload] and
  /// receive the URL after the upload.
  ///
  /// You can then use [Image.network] or similar to display that URL.
  ///
  /// ```
  /// final media = await FirebaseStorageCore.uploadWithBytes(bytes, "png");
  /// if(media == null) return;
  /// Image.network(media.url);
  /// ```
  static Future<String> uploadWithBytes(
      Uint8List bytes, String extension) async {
    assert(bytes.isNotEmpty, "Path is empty.");
    assert(extension.isNotEmpty, "Extension is empty.");
    final storage = readProvider(firebaseStorageProvider("$uuid.$extension"));
    await storage.uploadWithBytes(bytes);
    return storage.url;
  }
}
